@@ -308,7 +308,8 @@ WindowInfoWrap XWindowInterface::requestInfo(WindowId wid) const
                             | NET::WMName
                             | NET::WMVisibleName,
                               NET::WM2WindowClass
-                            | NET::WM2Activities};
+                            | NET::WM2Activities
+                            | NET::WM2TransientFor};
 
     //! update desktop id
 
@@ -320,9 +321,12 @@ WindowInfoWrap XWindowInterface::requestInfo(WindowId wid) const
 
     WindowInfoWrap winfoWrap;
 
-    if (isValidWindow(winfo) && !isPlasmaDesktop) {
+    if (!winfo.valid()) {
+        winfoWrap.setIsValid(false);
+    } else if (isValidWindow(winfo) && !isPlasmaDesktop) {
         winfoWrap.setIsValid(true);
         winfoWrap.setWid(wid);
+        winfoWrap.setParentId(winfo.transientFor());
         winfoWrap.setIsActive(KWindowSystem::activeWindow() == wid.value<WId>());
         winfoWrap.setIsMinimized(winfo.hasState(NET::Hidden));
         winfoWrap.setIsMaxVert(winfo.hasState(NET::MaxVert));
@@ -342,6 +346,7 @@ WindowInfoWrap XWindowInterface::requestInfo(WindowId wid) const
         winfoWrap.setIsValid(true);
         winfoWrap.setIsPlasmaDesktop(true);
         winfoWrap.setWid(wid);
+        winfoWrap.setParentId(0);
         winfoWrap.setHasSkipTaskbar(true);
     }
 
@@ -642,7 +647,7 @@ void XWindowInterface::windowChangedProxy(WId wid, NET::Properties prop1, NET::P
     //! ignore when the user presses a key, or a window is sending X events etc.
     //! without needing to (e.g. Firefox, https://bugzilla.mozilla.org/show_bug.cgi?id=1389953)
     //! NET::WM2UserTime, NET::WM2IconPixmap etc....
-    if (prop1 == 0 && !(prop2 & NET::WM2Activities)) {
+    if (prop1 == 0 && !(prop2 & (NET::WM2Activities | NET::WM2TransientFor))) {
         return;
     }
 
@@ -653,6 +658,7 @@ void XWindowInterface::windowChangedProxy(WId wid, NET::Properties prop1, NET::P
           && !(prop1 & NET::ActiveWindow)
           && !(prop1 & NET::WMDesktop)
           && !(prop1 & (NET::WMName | NET::WMVisibleName)
+          && !(prop2 & NET::WM2TransientFor)
           && !(prop2 & NET::WM2Activities)) ) {
         return;
     }
